.. xpaw documentation master file, created by
   sphinx-quickstart on Thu Mar 16 11:08:48 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


============================
xpaw |version| documentation
============================

Key Features
============

- Provides a web scraping framework used to crawl web pages.
- Provides data extraction tools used to extract structured data from web pages.

Getting started
===============

.. toctree::
   :maxdepth: 2

   intro/install
   intro/quickstart

All the rest
============

.. toctree::
   :maxdepth: 1

   changelog
